%
\def\Genealogy@Version{2014/09/19, v. 0.1}
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{genealogy}[\Genealogy@Version]
%
\LoadClass{article}
%
\RequirePackage{tikz}
\usetikzlibrary{trees}
\usetikzlibrary{calc}
%
\RequirePackage[paperwidth=\maxdimen,paperheight=\maxdimen]{geometry}
%
\RequirePackage[active,tightpage]{preview}
\PreviewEnvironment{tikzpicture}
%
\setlength\PreviewBorder{5pt}
%
\newcommand{\childof}[3]{
  \draw [child] (#1) |- ($ (#2) + (#3) $) -| (#2);
}
\newcommand{\childofunion}[3]{\childof{#1}{#3}{0,1.0}\childof{#2}{#3}{0,1.0}}
\newcommand{\childofsecondunion}[3]{\childof{#1}{#3}{0,1.2}\childof{#2}{#3}{0,1.2}}
\newcommand{\childofthridunion}[3]{\childof{#1}{#3}{0,0.8}\childof{#2}{#3}{0,0.8}}
\newcommand{\married}[2]{
  \draw [link] (#1) -- node[above] {\textmarried} (#2);
}
\newcommand{\divorced}[2]{
  \draw [link] (#1) -- node[above] {\textdivorced} (#2);
}
\newcommand{\link}[2]{
  \draw [link] (#1) -- (#2);
}
\newcommand{\person}[5]{
  \node [#5] (#1) at ($ 2 *(#2, 0) - 2 *(0, #3) + mod(#3, 2) *(1, 0) $) {#4};
}
%
\newcommand{\resetoffset}{
  \edef\offset{0}
  \edef\lastlevel{\ifx\undefined\lastlevel0\else\lastlevel+1\fi}
}
\newcommand{\shiftoffset}[1]{\edef\offset{\offset+#1}}
%
\newcommand{\addperson}[3]{
  \edef\offset{\ifx\undefined\offset0\else\offset\fi}
  \edef\lastlevel{\ifx\undefined\lastlevel0\else\lastlevel\fi}
  \person{#1}{\offset}{\lastlevel}{#2}{#3}
  \edef\offset{\offset+1}
}
\newcommand{\male}[2]{\addperson{#1}{#2}{male}}
\newcommand{\female}[2]{\addperson{#1}{#2}{female}}
%
\AtBeginDocument{

  \footnotesize

  \tikzstyle{person} = [rectangle,draw,minimum width=10em]
  \tikzstyle{female} = [person,fill=red!20,rounded corners]
  \tikzstyle{male} = [person,fill=blue!20]
  \tikzstyle{child} = [->,>=stealth,thick]
  \tikzstyle{link} = [-,thick]

  \begin{tikzpicture}[x=24mm,y=10mm]
}
%
\AtEndDocument{
  \end{tikzpicture}
}
